@@ -4,11 +4,6 @@ from unittest.mock import Mock, patch
 
 from botocore.exceptions import ClientError
 
-from sagemaker_studio._openapi.models import (
-    ListExecutionsRequest,
-    StartExecutionRequest,
-    StopExecutionRequest,
-)
 from sagemaker_studio.execution.remote_execution_client import (
     DEFAULT_IMAGE_VERSION,
     DEFAULT_INSTANCE_TYPE,
@@ -101,17 +96,23 @@ class TestRemoteExecutionClient(unittest.TestCase):
             "status": "ACTIVE",
         }
 
-    def test_execution_client_init_fails_no_domain_identifier(self):
+    def test_execution_client_api_fails_no_domain_identifier(self):
         execution_config = ExecutionConfig()
         execution_config.project_identifier = "project_123"
         with self.assertRaises(InternalServerError):
-            RemoteExecutionClient(self.datazone_api, self.project_api, execution_config)
+            remote_client = RemoteExecutionClient(
+                self.datazone_api, self.project_api, execution_config
+            )
+            remote_client.list_executions()
 
-    def test_execution_client_init_fails_no_project_identifier(self):
+    def test_execution_client_api_fails_no_project_identifier(self):
         execution_config = ExecutionConfig()
         execution_config.domain_identifier = "domain_123"
         with self.assertRaises(InternalServerError):
-            RemoteExecutionClient(self.datazone_api, self.project_api, execution_config)
+            remote_client = RemoteExecutionClient(
+                self.datazone_api, self.project_api, execution_config
+            )
+            remote_client.list_executions()
 
     def test_validate_execution_name(self):
         # valid name can have 26 chars maximum
@@ -207,13 +208,18 @@ class TestRemoteExecutionClient(unittest.TestCase):
 
     def test_validate_image_version(self):
         # Test valid versions
-        self.assertTrue(RemoteExecutionClient.validate_image_version("2.2.0"))
-        self.assertTrue(RemoteExecutionClient.validate_image_version("2.2"))
+        self.assertTrue(RemoteExecutionClient.validate_image_version("2.6"))
+        self.assertTrue(RemoteExecutionClient.validate_image_version("2.6.1"))
+        self.assertTrue(RemoteExecutionClient.validate_image_version("2.7"))
+        self.assertTrue(RemoteExecutionClient.validate_image_version("2.8"))
+        self.assertTrue(RemoteExecutionClient.validate_image_version("2.8.1"))
         self.assertTrue(RemoteExecutionClient.validate_image_version("2"))
         self.assertTrue(RemoteExecutionClient.validate_image_version("3.0.0"))
         self.assertTrue(RemoteExecutionClient.validate_image_version("3.0"))
         self.assertTrue(RemoteExecutionClient.validate_image_version("3"))
 
+        self.assertFalse(RemoteExecutionClient.validate_image_version("2.2.0"))
+        self.assertFalse(RemoteExecutionClient.validate_image_version("2.2"))
         self.assertFalse(RemoteExecutionClient.validate_image_version("1.0"))
         self.assertFalse(RemoteExecutionClient.validate_image_version("2.0.1"))
         self.assertFalse(RemoteExecutionClient.validate_image_version("2.1"))
@@ -225,6 +231,10 @@ class TestRemoteExecutionClient(unittest.TestCase):
     def test_list_executions(self):
         mock_sagemaker_client = Mock()
         self.remote_client.sagemaker_client = mock_sagemaker_client
+        self.remote_client.ec2_client = self.remote_client.ssm_client = Mock()
+        self.remote_client.security_group = self.remote_client.subnets = (
+            self.remote_client.user_role_arn
+        ) = self.remote_client.kms_key_identifier = Mock()
 
         mock_sagemaker_client.search.return_value = {
             "Results": [
@@ -262,7 +272,7 @@ class TestRemoteExecutionClient(unittest.TestCase):
         }
 
         # test list_executions
-        response = self.remote_client.list_executions(ListExecutionsRequest())
+        response = self.remote_client.list_executions()
         executions = response.get("executions")
         self.assertEqual(len(executions), 2)  # type: ignore
         self.assertEqual(executions[0].get("id"), "job-1")  # type: ignore
@@ -278,6 +288,10 @@ class TestRemoteExecutionClient(unittest.TestCase):
         # Arrange
         mock_sagemaker_client = Mock()
         self.remote_client.sagemaker_client = mock_sagemaker_client
+        self.remote_client.security_group = self.remote_client.subnets = (
+            self.remote_client.user_role_arn
+        ) = self.remote_client.kms_key_identifier = Mock()
+        self.remote_client.ec2_client = self.remote_client.ssm_client = Mock()
         client_error = ClientError(
             error_response={
                 "Error": {
@@ -301,11 +315,9 @@ class TestRemoteExecutionClient(unittest.TestCase):
         )
         mock_sagemaker_client.stop_training_job.side_effect = client_error
 
-        request = StopExecutionRequest(execution_id="test_job_id")
-
         # Act and Assert
         with self.assertRaises(ConflictError) as context:
-            self.remote_client.stop_execution(request)
+            self.remote_client.stop_execution(execution_id="test_job_id")
 
         self.assertEqual(
             str(context.exception),
@@ -341,6 +353,7 @@ class TestRemoteExecutionClient(unittest.TestCase):
                 {"name": "SubnetIds", "value": "subnet-12345678,subnet-87654321"},
                 {"name": "SecurityGroupId", "value": "sg-12345678"},
                 {"name": "s3BucketPath", "value": "s3://my-bucket/my-project/"},
+                {"name": "codeRepositoryName", "value": "my-code-repository"},
             ],
         }
         self.remote_client._utils = Mock()
@@ -356,22 +369,9 @@ class TestRemoteExecutionClient(unittest.TestCase):
         self.remote_client.security_group = "sg-12345678"
         self.remote_client.subnets = ["subnet-12345678"]
 
-        request = StartExecutionRequest(
-            execution_name="test-job",
-            compute={
-                "instance_type": "ml.m5.large",
-                "volume_size_in_gb": 50,
-                "image_details": {
-                    "image_name": "sagemaker-distribution-embargoed-prod",
-                    "image_version": "3.0.0",
-                },
-            },
-            input_config={"notebook_config": {"input_path": "src/test.ipynb"}},
-            termination_condition={"max_runtime_in_seconds": 3600},
-            output_config={"notebook_config": {"input_path": "src/test.ipynb"}},
+        ecr_uri = (
+            "123456123456.dkr.ecr.us-west-2.amazonaws.com/sagemaker-distribution-prod:3.0.0-cpu"
         )
-
-        ecr_uri = "123456123456.dkr.ecr.us-west-2.amazonaws.com/sagemaker-distribution-embargoed-prod:3.0.0-reinvent2024-cpu"
         input = {"path": "s3://my-bucket/my-project/workflows/project-files", "file": "test.ipynb"}
         output = {"path": "s3://my-bucket/my-project/workflows/output", "file": "_test.ipynb"}
 
@@ -393,7 +393,21 @@ class TestRemoteExecutionClient(unittest.TestCase):
         self.remote_client.ssm_client = mock_ssm_client
 
         # Act
-        result = self.remote_client.start_execution(request)
+        result = self.remote_client.start_execution(
+            execution_name="test-job",
+            compute={
+                "instance_type": "ml.m5.large",
+                "volume_size_in_gb": 50,
+                "image_details": {
+                    "image_name": "sagemaker-distribution-prod",
+                    "image_version": "3.0.0",
+                },
+            },
+            input_config={"notebook_config": {"input_path": "src/test.ipynb"}},
+            termination_condition={"max_runtime_in_seconds": 3600},
+            output_config={"notebook_config": {"input_path": "src/test.ipynb"}},
+            tags={"a": "b"},
+        )
 
         # Assert
         mock_sagemaker_client.create_training_job.assert_called_once()
@@ -424,6 +438,7 @@ class TestRemoteExecutionClient(unittest.TestCase):
         self.assertEqual(call_args["VpcConfig"]["Subnets"], self.remote_client.subnets)
 
         self.assertEqual(result["execution_id"], "test-job-1234-5678-9012-3456")
+        self.assertEqual(result["tags"], {"a": "b"})
 
     @patch("uuid.uuid4")
     def test_start_execution_with_minimum_input_fields_provided(self, mock_uuid):
@@ -449,6 +464,7 @@ class TestRemoteExecutionClient(unittest.TestCase):
                 {"name": "SubnetIds", "value": "subnet-12345678,subnet-87654321"},
                 {"name": "SecurityGroupId", "value": "sg-12345678"},
                 {"name": "s3BucketPath", "value": "s3://my-bucket/my-project/"},
+                {"name": "codeRepositoryName", "value": "my-code-repository"},
             ],
         }
         self.remote_client._utils = Mock()
@@ -463,11 +479,6 @@ class TestRemoteExecutionClient(unittest.TestCase):
         self.remote_client.security_group = "sg-12345678"
         self.remote_client.subnets = ["subnet-12345678"]
 
-        request = StartExecutionRequest(
-            execution_name="test-job",
-            input_config={"notebook_config": {"input_path": "src/test.ipynb"}},
-        )
-
         input = {"path": "s3://my-bucket/my-project/workflows/project-files", "file": "test.ipynb"}
         output = {"path": "s3://my-bucket/my-project/workflows/output", "file": "_test.ipynb"}
 
@@ -488,14 +499,17 @@ class TestRemoteExecutionClient(unittest.TestCase):
         self.remote_client.ssm_client = mock_ssm_client
 
         # Act
-        result = self.remote_client.start_execution(request)
+        result = self.remote_client.start_execution(
+            execution_name="test-job",
+            input_config={"notebook_config": {"input_path": "src/test.ipynb"}},
+        )
 
         # Assert
         mock_sagemaker_client.create_training_job.assert_called_once()
         call_args = mock_sagemaker_client.create_training_job.call_args[1]
 
         self.assertEqual(call_args["TrainingJobName"], "test-job-1234-5678-9012-3456")
-        default_ecr_uri = f"123456123456.dkr.ecr.us-west-2.amazonaws.com/sagemaker-distribution-embargoed-loadtest:{DEFAULT_IMAGE_VERSION}-reinvent2024-cpu"
+        default_ecr_uri = f"123456123456.dkr.ecr.us-west-2.amazonaws.com/sagemaker-distribution-loadtest:{DEFAULT_IMAGE_VERSION}-cpu"
         self.assertEqual(call_args["AlgorithmSpecification"]["TrainingImage"], default_ecr_uri)
         self.assertEqual(call_args["RoleArn"], self.remote_client.user_role_arn)
         self.assertEqual(call_args["OutputDataConfig"]["S3OutputPath"], output["path"])
