@@ -1,5 +1,5 @@
 import os
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 try:
     import requests
@@ -53,9 +53,7 @@ class LocalExecutionClient(ExecutionClient):
     This method fetches the details of an execution based on the provided request.
 
     Args:
-        request (GetExecutionRequest): An object containing the necessary information
-        to identify and retrieve the execution details. This typically includes
-        - execution_id: The unique identifier of the execution to retrieve
+        execution_id (str): The unique identifier of the execution to retrieve
 
     Returns:
         dict: A dictionary containing the execution details. It includes information such as:
@@ -77,7 +75,12 @@ class LocalExecutionClient(ExecutionClient):
         print(f"Execution status: {execution_details['status']}")
     """
 
-    def get_execution(self, request: GetExecutionRequest) -> dict:
+    def get_execution(self, execution_id: str) -> dict:
+        parameters = {"execution_id": execution_id}
+        request = GetExecutionRequest(**parameters)
+        return self._get_execution_internal(request)
+
+    def _get_execution_internal(self, request: GetExecutionRequest) -> dict:
         job_id: str = request.execution_id
         url: str = f"{LocalExecutionUtils.LOCAL_JOBS_SCHEDULER_URL}/{job_id}"
 
@@ -88,7 +91,7 @@ class LocalExecutionClient(ExecutionClient):
                 response = {
                     "execution_id": job_id,
                     "status": job_data["status"],
-                    "start_time": job_data["start_time"],
+                    "start_time": job_data.get("start_time", None),
                     **(
                         {"end_time": job_data.get("end_time")}
                         if job_data.get("end_time") is not None
@@ -99,7 +102,7 @@ class LocalExecutionClient(ExecutionClient):
                 if job_data["status"] == "FAILED":
                     response["error_details"] = {
                         "error_type": ErrorType.SERVER_ERROR,
-                        "error_message": job_data["status_message"],
+                        "error_message": job_data.get("status_message", None),
                     }
 
                 job_files = job_data["job_files"]
@@ -116,7 +119,7 @@ class LocalExecutionClient(ExecutionClient):
                 return {
                     "execution_id": job_id,
                     "status": job_data["status"],
-                    "start_time": job_data["start_time"],
+                    "start_time": job_data.get("start_time", None),
                     **(
                         {"end_time": job_data.get("end_time")}
                         if job_data.get("end_time") is not None
@@ -133,15 +136,13 @@ class LocalExecutionClient(ExecutionClient):
     It can be used to query executions based on various filters, pagination, and sorting options.
 
     Args:
-        request (ListExecutionsRequest): An object containing the parameters for listing executions.
-            This may include:
-            - start_time_after: Filter executions starting after a specific time
-            - name_contains: Filter executions whose name contains a specific string
-            - status: Filter executions by their current status (e.g., 'IN_PROGRESS', 'COMPLETED', 'FAILED', 'STOPPING', 'STOPPED')
-            - max_results: Maximum number of results to return
-            - next_token: Token for pagination
-            - sort_by: Field to sort the results by (e.g., 'start_time', 'status', 'end_time', 'name')
-            - sort_order: ASCENDING or DESCENDING order
+        start_time_after (Optional[int]): Filter executions starting after a specific time
+        name_contains (Optional[str]): Filter executions whose name contains a specific string
+        status (Optional[str]): Filter executions by their current status (e.g., 'IN_PROGRESS', 'COMPLETED', 'FAILED', 'STOPPING', 'STOPPED')
+        sort_order (Optional[str]): Order to return results (e.g., 'ASCENDING' or 'DESCENDING')
+        sort_by (Optional[str]): Field to sort the results by (e.g., 'NAME', 'STATUS', 'START_TIME', 'END_TIME')
+        next_token (Optional[str]): Token for pagination
+        max_results (Optional[int]): Maximum number of results to return
 
     Returns:
         dict: A dictionary containing the list of executions and metadata. Typical structure:
@@ -183,7 +184,36 @@ class LocalExecutionClient(ExecutionClient):
             # ... make next request
     """
 
-    def list_executions(self, request: ListExecutionsRequest) -> dict:
+    def list_executions(
+        self,
+        start_time_after: Optional[int] = None,
+        name_contains: Optional[str] = None,
+        status: Optional[str] = None,
+        sort_order: Optional[str] = None,
+        sort_by: Optional[str] = None,
+        next_token: Optional[str] = None,
+        max_results: Optional[int] = None,
+    ) -> dict:
+        parameters = {}
+        if start_time_after is not None:
+            parameters["start_time_after"] = start_time_after
+        if name_contains is not None:
+            parameters["name_contains"] = name_contains
+        if status is not None:
+            parameters["status"] = status
+        if sort_order is not None:
+            parameters["sort_order"] = sort_order
+        if sort_by is not None:
+            parameters["sort_by"] = sort_by
+        if next_token is not None:
+            parameters["next_token"] = next_token
+        if max_results is not None:
+            parameters["max_results"] = max_results
+
+        request = ListExecutionsRequest(**parameters)
+        return self._list_executions_internal(request)
+
+    def _list_executions_internal(self, request: ListExecutionsRequest) -> dict:
         try:
             search_sort_order = (
                 "asc"
@@ -208,7 +238,8 @@ class LocalExecutionClient(ExecutionClient):
             }
             job_scheduler_list_response: dict = LocalExecutionUtils.fetch_data(
                 LocalExecutionUtils.get_url_with_query_params(
-                    base_url=LocalExecutionUtils.LOCAL_JOBS_SCHEDULER_URL, params=query_params
+                    base_url=LocalExecutionUtils.LOCAL_JOBS_SCHEDULER_URL,
+                    params=query_params,
                 )
             )
             jobs_data = job_scheduler_list_response.get("jobs", [])
@@ -220,7 +251,7 @@ class LocalExecutionClient(ExecutionClient):
                         "id": item["job_id"],
                         "name": item["name"],
                         "status": item["status"],
-                        "start_time": item["start_time"],
+                        "start_time": item.get("start_time", None),
                         **(
                             {"end_time": item.get("end_time")}
                             if item.get("end_time") is not None
@@ -243,13 +274,11 @@ class LocalExecutionClient(ExecutionClient):
     Initiates a new execution in the user space based on the provided request parameters.
 
     Args:
-        request (StartExecutionRequest): An object containing the necessary information to star.
-        This typically includes:
-        - execution_name: A unique name for the execution
-        - execution_type: The type of execution (e.g., 'NOTEBOOK')
-        - input_config: Configuration for the input data for the execution
-        - output_config: Configuration for the outputs like output formats
-        - client_token: A unique token to ensure idempotency
+        execution_name (str): A unique name for the execution
+        execution_type (Optional[str]): The type of execution (e.g., 'NOTEBOOK')
+        input_config (Dict[str, Any]): Configuration for the input data for the execution
+        output_config (Optional[Dict[str, Any]]): Configuration for the outputs like output formats
+        client_token (Optional[str]): A unique token to ensure idempotency
 
     Returns:
         dict: A dictionary containing information about the started execution. Typical structure:
@@ -289,7 +318,25 @@ class LocalExecutionClient(ExecutionClient):
         print(f"Current status: {result['status']}")
     """
 
-    def start_execution(self, request: StartExecutionRequest) -> dict:
+    def start_execution(
+        self,
+        execution_name: str,
+        input_config: Dict[str, Any] = {},
+        **kwargs,
+    ) -> dict:
+        # Convert underscores to hyphens in execution_name to meet regex validation
+        execution_name = execution_name.replace("_", "-")
+
+        parameters = {
+            "execution_name": execution_name,
+            "input_config": input_config,
+            **kwargs,
+        }
+
+        request = StartExecutionRequest(**parameters)
+        return self._start_execution_internal(request)
+
+    def _start_execution_internal(self, request: StartExecutionRequest) -> dict:
         import psutil
 
         self.xsrf = self.__set_cookies()
@@ -390,9 +437,7 @@ class LocalExecutionClient(ExecutionClient):
     its current state.
 
     Args:
-        request (StopExecutionRequest): An object containing the necessary information to identify
-        and stop the execution. This typically includes:
-        - execution_id: The unique identifier of the execution to stop
+        execution_id (str): The unique identifier of the execution to stop
 
     Returns:
         None: This method doesn't return any value. The absence of an exception indicates
@@ -417,10 +462,15 @@ class LocalExecutionClient(ExecutionClient):
             print("Execution not found")
     """
 
-    def stop_execution(self, request: StopExecutionRequest) -> None:
+    def stop_execution(self, execution_id: str) -> None:
+        parameters = {"execution_id": execution_id}
+        request = StopExecutionRequest(**parameters)
+        return self._stop_execution_internal(request)
+
+    def _stop_execution_internal(self, request: StopExecutionRequest) -> None:
         self.xsrf = self.__set_cookies()
         url = f"{LocalExecutionUtils.LOCAL_JOBS_SCHEDULER_URL}/{request.execution_id}"
-        get_execution_status = self.get_execution(
+        get_execution_status = self._get_execution_internal(
             GetExecutionRequest(execution_id=request.execution_id)
         ).get("status")
         if get_execution_status not in LocalExecutionStoppableStatuses.__members__:
